@@ -4,7 +4,7 @@ from __future__ import print_function
 import grpc
 
 # import aa_service_pb2_grpc,interceptor
-from . import aa_service_pb2_grpc,interceptor
+from . import admin_pb2_grpc,interceptor
 
 
 SERVER_URL = "adminv2.api.formalcloud.net"
@@ -24,5 +24,5 @@ class Client(object):
         channel = grpc.secure_channel(SERVER_URL, grpc.ssl_channel_credentials())
         interceptors = [interceptor.MetadataClientInterceptor(client_id, api_key)]
         channel = grpc.intercept_channel(channel, *interceptors)
-        stub = aa_service_pb2_grpc.AdminApiServiceStub(channel)
-        self.Service = stub
\ No newline at end of file
+        stub = admin_pb2_grpc.InventoryServiceStub(channel)
+        self.InventoryService = stub
\ No newline at end of file
